@@ -8,8 +8,10 @@ require "active_support/all"
 # observability.
 module Labkit
   autoload :Correlation, "labkit/correlation"
+  autoload :Context, "labkit/context"
   autoload :Tracing, "labkit/tracing"
   autoload :Logging, "labkit/logging"
+  autoload :Middleware, "labkit/middleware"
 end
 
 # rubocop:enable Naming/FileName
